#open this flag when get latest build env
%bcond_with tests

Summary: Tracks and displays system calls associated with a running process
Name: strace
Version: 6.4
Release: 2%{?dist}
License: LGPL-2.1-or-later and GPL-2.0-or-later
URL: https://strace.io
Source: https://strace.io/files/%{version}/strace-%{version}.tar.xz

# as upstream haven't solve the bpf output log, we have to disable 
# this test temporarily. https://github.com/strace/strace/issues/94
Patch0001: 0001-disable-bpf-obj_get_info_by_fd-prog-test.patch
BuildRequires: xz
BuildRequires: gcc gzip make
BuildRequires: pkgconfig(bluez)
BuildRequires: elfutils-devel binutils-devel
BuildRequires: libselinux-devel


%description
The strace program intercepts and records the system calls called and
received by a running process.  Strace can print a record of each
system call, its arguments and its return value.  Strace is useful for
diagnosing problems and debugging, as well as for instructional
purposes.

Install strace if you need a tool to track the system calls made and
received by a process.

%prep
%autosetup -p1
echo -n %version-%release > .tarball-version
echo -n 2023 > .year
echo -n 2023-06-11 > doc/.strace.1.in.date
echo -n 2022-01-01 > doc/.strace-log-merge.1.in.date

%build
echo 'BEGIN OF BUILD ENVIRONMENT INFORMATION'
uname -a |head -1
libc="$(ldd /bin/sh |sed -n 's|^[^/]*\(/[^ ]*/libc\.so[^ ]*\).*|\1|p' |head -1)"
$libc |head -1
file -L /bin/sh
gcc --version |head -1
ld --version |head -1
kver="$(printf '%%s\n%%s\n' '#include <linux/version.h>' 'LINUX_VERSION_CODE' | gcc -E -P -)"
printf 'kernel-headers %%s.%%s.%%s\n' $((kver/65536)) $((kver/256%%256)) $((kver%%256))
echo 'END OF BUILD ENVIRONMENT INFORMATION'

CFLAGS_FOR_BUILD="$RPM_OPT_FLAGS"; export CFLAGS_FOR_BUILD
%configure --enable-mpers=check
%make_build

%install
%make_install

for f in ChangeLog ChangeLog-CVS; do
	gzip -9n < "$f" > "$f".gz &
done
wait

%check
%if %{with tests}
%{buildroot}%{_bindir}/strace -V
%make_build -k check VERBOSE=1
echo 'BEGIN OF TEST SUITE INFORMATION'
tail -n 99999 -- tests*/test-suite.log tests*/ksysent.gen.log
find tests* -type f -name '*.log' -print0 |
      xargs -r0 grep -H '^KERNEL BUG:' -- ||:
echo 'END OF TEST SUITE INFORMATION'
%endif

%files
%license COPYING
%doc CREDITS ChangeLog.gz ChangeLog-CVS.gz  NEWS README
%{_bindir}/strace
%{_bindir}/strace-log-merge
%{_mandir}/man1/*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.4-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Aug 21 2023 Wang Guodong <gordonwwang@tencent.com> - 6.4-1
- Upgrade to version 6.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.1-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Feb 24 2023 Shuo Wang <abushwang@tencent.com> - 6.1-1
- update to 6.1

* Mon Apr 25 2022 Lin Yi <nilusyi@tencent.com> - 5.17-1
- Package init
